@@ -1,5 +1,4 @@
 """Unicode Properties from Unicode version 13.0.0 (autogen)."""
-from __future__ import unicode_literals
 
 unicode_joining_group = {
     "^africanfeh": "\x00-\u08ba\u08bc-\U0010ffff",
@@ -208,108 +207,108 @@ unicode_joining_group = {
     "zhain": "\u074d"
 }
 ascii_joining_group = {
-    "^africanfeh": "\x00-\xff",
-    "^africannoon": "\x00-\xff",
-    "^africanqaf": "\x00-\xff",
-    "^ain": "\x00-\xff",
-    "^alaph": "\x00-\xff",
-    "^alef": "\x00-\xff",
-    "^beh": "\x00-\xff",
-    "^beth": "\x00-\xff",
-    "^burushaskiyehbarree": "\x00-\xff",
-    "^dal": "\x00-\xff",
-    "^dalathrish": "\x00-\xff",
-    "^e": "\x00-\xff",
-    "^farsiyeh": "\x00-\xff",
-    "^fe": "\x00-\xff",
-    "^feh": "\x00-\xff",
-    "^finalsemkath": "\x00-\xff",
-    "^gaf": "\x00-\xff",
-    "^gamal": "\x00-\xff",
-    "^hah": "\x00-\xff",
-    "^hanifirohingyakinnaya": "\x00-\xff",
-    "^hanifirohingyapa": "\x00-\xff",
-    "^he": "\x00-\xff",
-    "^heh": "\x00-\xff",
-    "^hehgoal": "\x00-\xff",
-    "^heth": "\x00-\xff",
-    "^kaf": "\x00-\xff",
-    "^kaph": "\x00-\xff",
-    "^khaph": "\x00-\xff",
-    "^knottedheh": "\x00-\xff",
-    "^lam": "\x00-\xff",
-    "^lamadh": "\x00-\xff",
-    "^malayalambha": "\x00-\xff",
-    "^malayalamja": "\x00-\xff",
-    "^malayalamlla": "\x00-\xff",
-    "^malayalamllla": "\x00-\xff",
-    "^malayalamnga": "\x00-\xff",
-    "^malayalamnna": "\x00-\xff",
-    "^malayalamnnna": "\x00-\xff",
-    "^malayalamnya": "\x00-\xff",
-    "^malayalamra": "\x00-\xff",
-    "^malayalamssa": "\x00-\xff",
-    "^malayalamtta": "\x00-\xff",
-    "^manichaeanaleph": "\x00-\xff",
-    "^manichaeanayin": "\x00-\xff",
-    "^manichaeanbeth": "\x00-\xff",
-    "^manichaeandaleth": "\x00-\xff",
-    "^manichaeandhamedh": "\x00-\xff",
-    "^manichaeanfive": "\x00-\xff",
-    "^manichaeangimel": "\x00-\xff",
-    "^manichaeanheth": "\x00-\xff",
-    "^manichaeanhundred": "\x00-\xff",
-    "^manichaeankaph": "\x00-\xff",
-    "^manichaeanlamedh": "\x00-\xff",
-    "^manichaeanmem": "\x00-\xff",
-    "^manichaeannun": "\x00-\xff",
-    "^manichaeanone": "\x00-\xff",
-    "^manichaeanpe": "\x00-\xff",
-    "^manichaeanqoph": "\x00-\xff",
-    "^manichaeanresh": "\x00-\xff",
-    "^manichaeansadhe": "\x00-\xff",
-    "^manichaeansamekh": "\x00-\xff",
-    "^manichaeantaw": "\x00-\xff",
-    "^manichaeanten": "\x00-\xff",
-    "^manichaeanteth": "\x00-\xff",
-    "^manichaeanthamedh": "\x00-\xff",
-    "^manichaeantwenty": "\x00-\xff",
-    "^manichaeanwaw": "\x00-\xff",
-    "^manichaeanyodh": "\x00-\xff",
-    "^manichaeanzayin": "\x00-\xff",
-    "^meem": "\x00-\xff",
-    "^mim": "\x00-\xff",
+    "^africanfeh": "\x00-\U0010ffff",
+    "^africannoon": "\x00-\U0010ffff",
+    "^africanqaf": "\x00-\U0010ffff",
+    "^ain": "\x00-\U0010ffff",
+    "^alaph": "\x00-\U0010ffff",
+    "^alef": "\x00-\U0010ffff",
+    "^beh": "\x00-\U0010ffff",
+    "^beth": "\x00-\U0010ffff",
+    "^burushaskiyehbarree": "\x00-\U0010ffff",
+    "^dal": "\x00-\U0010ffff",
+    "^dalathrish": "\x00-\U0010ffff",
+    "^e": "\x00-\U0010ffff",
+    "^farsiyeh": "\x00-\U0010ffff",
+    "^fe": "\x00-\U0010ffff",
+    "^feh": "\x00-\U0010ffff",
+    "^finalsemkath": "\x00-\U0010ffff",
+    "^gaf": "\x00-\U0010ffff",
+    "^gamal": "\x00-\U0010ffff",
+    "^hah": "\x00-\U0010ffff",
+    "^hanifirohingyakinnaya": "\x00-\U0010ffff",
+    "^hanifirohingyapa": "\x00-\U0010ffff",
+    "^he": "\x00-\U0010ffff",
+    "^heh": "\x00-\U0010ffff",
+    "^hehgoal": "\x00-\U0010ffff",
+    "^heth": "\x00-\U0010ffff",
+    "^kaf": "\x00-\U0010ffff",
+    "^kaph": "\x00-\U0010ffff",
+    "^khaph": "\x00-\U0010ffff",
+    "^knottedheh": "\x00-\U0010ffff",
+    "^lam": "\x00-\U0010ffff",
+    "^lamadh": "\x00-\U0010ffff",
+    "^malayalambha": "\x00-\U0010ffff",
+    "^malayalamja": "\x00-\U0010ffff",
+    "^malayalamlla": "\x00-\U0010ffff",
+    "^malayalamllla": "\x00-\U0010ffff",
+    "^malayalamnga": "\x00-\U0010ffff",
+    "^malayalamnna": "\x00-\U0010ffff",
+    "^malayalamnnna": "\x00-\U0010ffff",
+    "^malayalamnya": "\x00-\U0010ffff",
+    "^malayalamra": "\x00-\U0010ffff",
+    "^malayalamssa": "\x00-\U0010ffff",
+    "^malayalamtta": "\x00-\U0010ffff",
+    "^manichaeanaleph": "\x00-\U0010ffff",
+    "^manichaeanayin": "\x00-\U0010ffff",
+    "^manichaeanbeth": "\x00-\U0010ffff",
+    "^manichaeandaleth": "\x00-\U0010ffff",
+    "^manichaeandhamedh": "\x00-\U0010ffff",
+    "^manichaeanfive": "\x00-\U0010ffff",
+    "^manichaeangimel": "\x00-\U0010ffff",
+    "^manichaeanheth": "\x00-\U0010ffff",
+    "^manichaeanhundred": "\x00-\U0010ffff",
+    "^manichaeankaph": "\x00-\U0010ffff",
+    "^manichaeanlamedh": "\x00-\U0010ffff",
+    "^manichaeanmem": "\x00-\U0010ffff",
+    "^manichaeannun": "\x00-\U0010ffff",
+    "^manichaeanone": "\x00-\U0010ffff",
+    "^manichaeanpe": "\x00-\U0010ffff",
+    "^manichaeanqoph": "\x00-\U0010ffff",
+    "^manichaeanresh": "\x00-\U0010ffff",
+    "^manichaeansadhe": "\x00-\U0010ffff",
+    "^manichaeansamekh": "\x00-\U0010ffff",
+    "^manichaeantaw": "\x00-\U0010ffff",
+    "^manichaeanten": "\x00-\U0010ffff",
+    "^manichaeanteth": "\x00-\U0010ffff",
+    "^manichaeanthamedh": "\x00-\U0010ffff",
+    "^manichaeantwenty": "\x00-\U0010ffff",
+    "^manichaeanwaw": "\x00-\U0010ffff",
+    "^manichaeanyodh": "\x00-\U0010ffff",
+    "^manichaeanzayin": "\x00-\U0010ffff",
+    "^meem": "\x00-\U0010ffff",
+    "^mim": "\x00-\U0010ffff",
     "^nonjoining": "",
-    "^noon": "\x00-\xff",
-    "^nun": "\x00-\xff",
-    "^nya": "\x00-\xff",
-    "^pe": "\x00-\xff",
-    "^qaf": "\x00-\xff",
-    "^qaph": "\x00-\xff",
-    "^reh": "\x00-\xff",
-    "^reversedpe": "\x00-\xff",
-    "^rohingyayeh": "\x00-\xff",
-    "^sad": "\x00-\xff",
-    "^sadhe": "\x00-\xff",
-    "^seen": "\x00-\xff",
-    "^semkath": "\x00-\xff",
-    "^shin": "\x00-\xff",
-    "^straightwaw": "\x00-\xff",
-    "^swashkaf": "\x00-\xff",
-    "^syriacwaw": "\x00-\xff",
-    "^tah": "\x00-\xff",
-    "^taw": "\x00-\xff",
-    "^tehmarbuta": "\x00-\xff",
-    "^tehmarbutagoal": "\x00-\xff",
-    "^teth": "\x00-\xff",
-    "^waw": "\x00-\xff",
-    "^yeh": "\x00-\xff",
-    "^yehbarree": "\x00-\xff",
-    "^yehwithtail": "\x00-\xff",
-    "^yudh": "\x00-\xff",
-    "^yudhhe": "\x00-\xff",
-    "^zain": "\x00-\xff",
-    "^zhain": "\x00-\xff",
+    "^noon": "\x00-\U0010ffff",
+    "^nun": "\x00-\U0010ffff",
+    "^nya": "\x00-\U0010ffff",
+    "^pe": "\x00-\U0010ffff",
+    "^qaf": "\x00-\U0010ffff",
+    "^qaph": "\x00-\U0010ffff",
+    "^reh": "\x00-\U0010ffff",
+    "^reversedpe": "\x00-\U0010ffff",
+    "^rohingyayeh": "\x00-\U0010ffff",
+    "^sad": "\x00-\U0010ffff",
+    "^sadhe": "\x00-\U0010ffff",
+    "^seen": "\x00-\U0010ffff",
+    "^semkath": "\x00-\U0010ffff",
+    "^shin": "\x00-\U0010ffff",
+    "^straightwaw": "\x00-\U0010ffff",
+    "^swashkaf": "\x00-\U0010ffff",
+    "^syriacwaw": "\x00-\U0010ffff",
+    "^tah": "\x00-\U0010ffff",
+    "^taw": "\x00-\U0010ffff",
+    "^tehmarbuta": "\x00-\U0010ffff",
+    "^tehmarbutagoal": "\x00-\U0010ffff",
+    "^teth": "\x00-\U0010ffff",
+    "^waw": "\x00-\U0010ffff",
+    "^yeh": "\x00-\U0010ffff",
+    "^yehbarree": "\x00-\U0010ffff",
+    "^yehwithtail": "\x00-\U0010ffff",
+    "^yudh": "\x00-\U0010ffff",
+    "^yudhhe": "\x00-\U0010ffff",
+    "^zain": "\x00-\U0010ffff",
+    "^zhain": "\x00-\U0010ffff",
     "africanfeh": "",
     "africannoon": "",
     "africanqaf": "",
@@ -381,7 +380,7 @@ ascii_joining_group = {
     "manichaeanzayin": "",
     "meem": "",
     "mim": "",
-    "nonjoining": "\x00-\xff",
+    "nonjoining": "\x00-\U0010ffff",
     "noon": "",
     "nun": "",
     "nya": "",
